Package: pillar
Title: Coloured Formatting for Columns
Version: 1.8.0
Authors@R: 
    c(person(given = "Kirill",
             family = "M\u00fcller",
             role = c("aut", "cre"),
             email = "krlmlr+r@mailbox.org"),
      person(given = "Hadley",
             family = "Wickham",
             role = "aut"),
      person(given = "RStudio",
             role = "cph"))
Description: Provides 'pillar' and 'colonnade' generics designed
    for formatting columns of data using the full range of colours
    provided by modern terminals.
License: MIT + file LICENSE
URL: https://pillar.r-lib.org/, https://github.com/r-lib/pillar
BugReports: https://github.com/r-lib/pillar/issues
Imports: cli (>= 2.3.0), fansi, glue, lifecycle, rlang (>= 1.0.2), utf8
        (>= 1.1.0), utils, vctrs (>= 0.3.8)
Suggests: bit64, debugme, DiagrammeR, dplyr, formattable, ggplot2,
        knitr, lubridate, nanotime, nycflights13, palmerpenguins,
        rmarkdown, scales, stringi, survival, testthat (>= 3.1.1),
        tibble, units (>= 0.7.2), vdiffr, withr
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.2.0
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: format_multi_fuzz, format_multi_fuzz_2,
        format_multi, ctl_colonnade, ctl_colonnade_1, ctl_colonnade_2
Config/autostyle/scope: line_breaks
Config/autostyle/strict: true
Config/gha/extra-packages: DiagrammeR=?ignore-before-r=3.5.0
NeedsCompilation: no
Packaged: 2022-07-09 04:42:15 UTC; kirill
Author: Kirill Müller [aut, cre],
  Hadley Wickham [aut],
  RStudio [cph]
Maintainer: Kirill Müller <krlmlr+r@mailbox.org>
Repository: CRAN
Date/Publication: 2022-07-18 08:50:06 UTC
