# output test

    Code
      options(width = 100)
      tbl_format_setup(x, width = 4)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A
      #   data
      #   frame:
      #   3
      #   x
      #   3
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      #   with 3 more variables: column_zero_zero <dbl>, `col 01` <tbl[,3]>, `col 05` <ord>
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 5)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A
      #   data
      #   frame:
      #   3
      #   x
      #   3
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      #   with
      #   3
      #   more
      #   variables:
      #   column_zero_zero <dbl>,
      #   `col 01` <tbl[,3]>, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 6)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A
      #   data
      #   frame:
      #   3
      #   x
      #   3
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      #   with
      #   3
      #   more
      #   variables:
      #   column_zero_zero <dbl>,
      #   `col 01` <tbl[,3]>, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 7)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A
      #   data
      #   frame:
      #   3
      #   x
      #   3
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      #   with
      #   3
      #   more
      #   variables:
      #   column_zero_zero <dbl>,
      #   `col 01` <tbl[,3]>, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 8)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A
      #   data
      #   frame:
      #   3 x
      #   3
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      #   with
      #   3
      #   more
      #   variables:
      #   column_zero_zero <dbl>,
      #   `col 01` <tbl[,3]>, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 9)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame:
      #   3 x
      #   3
      <tbl_format_body(setup)>
        colum~1
          <dbl>
      1    1.23
      2    2.23
      3    3.23
      <tbl_format_footer(setup)>
      #   with
      #   2
      #   more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 10)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame:
      #   3 x 3
      <tbl_format_body(setup)>
        column~1
           <dbl>
      1     1.23
      2     2.23
      3     3.23
      <tbl_format_footer(setup)>
      #   with
      #   2
      #   more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 11)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame:
      #   3 x 3
      <tbl_format_body(setup)>
        column_~1
            <dbl>
      1      1.23
      2      2.23
      3      3.23
      <tbl_format_footer(setup)>
      # ... with
      #   2 more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 12)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame:
      #   3 x 3
      <tbl_format_body(setup)>
        column_z~1
             <dbl>
      1       1.23
      2       2.23
      3       3.23
      <tbl_format_footer(setup)>
      # ... with
      #   2 more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 13)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame: 3
      #   x 3
      <tbl_format_body(setup)>
        column_ze~1
              <dbl>
      1        1.23
      2        2.23
      3        3.23
      <tbl_format_footer(setup)>
      # ... with 2
      #   more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 14)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame: 3
      #   x 3
      <tbl_format_body(setup)>
        column_zer~1
               <dbl>
      1         1.23
      2         2.23
      3         3.23
      <tbl_format_footer(setup)>
      # ... with 2
      #   more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 15)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data
      #   frame: 3 x
      #   3
      <tbl_format_body(setup)>
        column_zero~1
                <dbl>
      1          1.23
      2          2.23
      3          3.23
      <tbl_format_footer(setup)>
      # ... with 2
      #   more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 16)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame:
      #   3 x 3
      <tbl_format_body(setup)>
        column_zero_~1
                 <dbl>
      1           1.23
      2           2.23
      3           3.23
      <tbl_format_footer(setup)>
      # ... with 2
      #   more
      #   variables:
      #   `col 01` <tbl[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 17)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame:
      #   3 x 3
      <tbl_format_body(setup)>
        colum~1 col 0~2
          <dbl> <chr>  
      1    1.23 a      
      2    2.23 b      
      3    3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3
      #   more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 18)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3
      #   x 3
      <tbl_format_body(setup)>
        column~1 col 0~2
           <dbl> <chr>  
      1     1.23 a      
      2     2.23 b      
      3     3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 19)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3
      #   x 3
      <tbl_format_body(setup)>
        column_~1 col 0~2
            <dbl> <chr>  
      1      1.23 a      
      2      2.23 b      
      3      3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and
      #   abbreviated ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 20)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x
      #   3
      <tbl_format_body(setup)>
        column_z~1 col 0~2
             <dbl> <chr>  
      1       1.23 a      
      2       2.23 b      
      3       3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and abbreviated
      #   variable ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 21)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x
      #   3
      <tbl_format_body(setup)>
        column_ze~1 col 0~2
              <dbl> <chr>  
      1        1.23 a      
      2        2.23 b      
      3        3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and abbreviated
      #   variable ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 22)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zer~1 col 0~2
               <dbl> <chr>  
      1         1.23 a      
      2         2.23 b      
      3         3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and abbreviated
      #   variable ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 23)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero~1 col 0~2
                <dbl> <chr>  
      1          1.23 a      
      2          2.23 b      
      3          3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>,
      #   and abbreviated
      #   variable names ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 24)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_~1 col 0~2
                 <dbl> <chr>  
      1           1.23 a      
      2           2.23 b      
      3           3.23 c      
      <tbl_format_footer(setup)>
      # ... with 3 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   `col 05` <ord>, and
      #   abbreviated
      #   variable names ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 25)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        colum~1 col 0~2 col 0~3
          <dbl> <chr>   <ord>  
      1    1.23 a       a      
      2    2.23 b       b      
      3    3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   and abbreviated
      #   variable names
      #   1: column_zero_zero, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 26)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column~1 col 0~2 col 0~3
           <dbl> <chr>   <ord>  
      1     1.23 a       a      
      2     2.23 b       b      
      3     3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   and abbreviated
      #   variable names
      #   1: column_zero_zero, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 27)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_~1 col 0~2 col 0~3
            <dbl> <chr>   <ord>  
      1      1.23 a       a      
      2      2.23 b       b      
      3      3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   and abbreviated
      #   variable names
      #   1: column_zero_zero, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 28)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_z~1 col 0~2 col 0~3
             <dbl> <chr>   <ord>  
      1       1.23 a       a      
      2       2.23 b       b      
      3       3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more
      #   variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>,
      #   and abbreviated
      #   variable names
      #   1: column_zero_zero, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 29)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_ze~1 col 0~2 col 0~3
              <dbl> <chr>   <ord>  
      1        1.23 a       a      
      2        2.23 b       b      
      3        3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable
      #   names
      #   1: column_zero_zero,
      #   2: `col 01`$`col 02`, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 30)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zer~1 col 0~2 col 0~3
               <dbl> <chr>   <ord>  
      1         1.23 a       a      
      2         2.23 b       b      
      3         3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable
      #   names
      #   1: column_zero_zero,
      #   2: `col 01`$`col 02`, ...
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 31)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero~1 col 0~2 col 0~3
                <dbl> <chr>   <ord>  
      1          1.23 a       a      
      2          2.23 b       b      
      3          3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: column_zero_zero,
      #   2: `col 01`$`col 02`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 32)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_~1 col 0~2 col 0~3
                 <dbl> <chr>   <ord>  
      1           1.23 a       a      
      2           2.23 b       b      
      3           3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: column_zero_zero,
      #   2: `col 01`$`col 02`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 33)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_z~1 col 0~2 col 0~3
                  <dbl> <chr>   <ord>  
      1            1.23 a       a      
      2            2.23 b       b      
      3            3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: column_zero_zero,
      #   2: `col 01`$`col 02`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 34)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 0~1 col 0~2
                   <dbl> <chr>   <ord>  
      1             1.23 a       a      
      2             2.23 b       b      
      3             3.23 c       c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`,
      #   2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 35)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01~1 col 0~2
                   <dbl> <chr>    <ord>  
      1             1.23 a        a      
      2             2.23 b        b      
      3             3.23 c        c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`,
      #   2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 36)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$~1 col 0~2
                   <dbl> <chr>     <ord>  
      1             1.23 a         a      
      2             2.23 b         b      
      3             3.23 c         c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`,
      #   2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 37)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$c~1 col 0~2
                   <dbl> <chr>      <ord>  
      1             1.23 a          a      
      2             2.23 b          b      
      3             3.23 c          c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`,
      #   2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 38)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$co~1 col 0~2
                   <dbl> <chr>       <ord>  
      1             1.23 a           a      
      2             2.23 b           b      
      3             3.23 c           c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 39)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col~1 col 0~2
                   <dbl> <chr>        <ord>  
      1             1.23 a            a      
      2             2.23 b            b      
      3             3.23 c            c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 40)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col ~1 col 0~2
                   <dbl> <chr>         <ord>  
      1             1.23 a             a      
      2             2.23 b             b      
      3             3.23 c             c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 41)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col 0~1 col 0~2
                   <dbl> <chr>          <ord>  
      1             1.23 a              a      
      2             2.23 b              b      
      3             3.23 c              c      
      <tbl_format_footer(setup)>
      # ... with 2 more variables:
      #   `col 01`$`col 03` <chr>,
      #   $`col 04` <int[,3]>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 42)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 0~1 $col ~2 col 0~3
                   <dbl> <chr>   <chr>   <ord>  
      1             1.23 a       A       a      
      2             2.23 b       B       b      
      3             3.23 c       C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 43)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01~1 $col ~2 col 0~3
                   <dbl> <chr>    <chr>   <ord>  
      1             1.23 a        A       a      
      2             2.23 b        B       b      
      3             3.23 c        C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 44)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$~1 $col ~2 col 0~3
                   <dbl> <chr>     <chr>   <ord>  
      1             1.23 a         A       a      
      2             2.23 b         B       b      
      3             3.23 c         C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 45)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$c~1 $col ~2 col 0~3
                   <dbl> <chr>      <chr>   <ord>  
      1             1.23 a          A       a      
      2             2.23 b          B       b      
      3             3.23 c          C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 46)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$co~1 $col ~2 col 0~3
                   <dbl> <chr>       <chr>   <ord>  
      1             1.23 a           A       a      
      2             2.23 b           B       b      
      3             3.23 c           C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 47)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col~1 $col ~2 col 0~3
                   <dbl> <chr>        <chr>   <ord>  
      1             1.23 a            A       a      
      2             2.23 b            B       b      
      3             3.23 c            C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 48)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col ~1 $col ~2 col 0~3
                   <dbl> <chr>         <chr>   <ord>  
      1             1.23 a             A       a      
      2             2.23 b             B       b      
      3             3.23 c             C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and
      #   abbreviated variable names
      #   1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 49)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col 0~1 $col ~2 col 0~3
                   <dbl> <chr>          <chr>   <ord>  
      1             1.23 a              A       a      
      2             2.23 b              B       b      
      3             3.23 c              C       c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04` <int[,3]>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 50)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 0~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>   <chr>     <int> <ord>  
      1             1.23 a       A             1 a      
      2             2.23 b       B             2 b      
      3             3.23 c       C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 51)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>    <chr>     <int> <ord>  
      1             1.23 a        A             1 a      
      2             2.23 b        B             2 b      
      3             3.23 c        C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 52)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>     <chr>     <int> <ord>  
      1             1.23 a         A             1 a      
      2             2.23 b         B             2 b      
      3             3.23 c         C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 53)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$c~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>      <chr>     <int> <ord>  
      1             1.23 a          A             1 a      
      2             2.23 b          B             2 b      
      3             3.23 c          C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 54)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$co~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>       <chr>     <int> <ord>  
      1             1.23 a           A             1 a      
      2             2.23 b           B             2 b      
      3             3.23 c           C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 55)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>        <chr>     <int> <ord>  
      1             1.23 a            A             1 a      
      2             2.23 b            B             2 b      
      3             3.23 c            C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 56)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col ~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>         <chr>     <int> <ord>  
      1             1.23 a             A             1 a      
      2             2.23 b             B             2 b      
      3             3.23 c             C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 57)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col 0~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>          <chr>     <int> <ord>  
      1             1.23 a              A             1 a      
      2             2.23 b              B             2 b      
      3             3.23 c              C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable:
      #   `col 01`$`col 04`[2:3] <int>, and abbreviated
      #   variable names 1: `col 01`$`col 02`, 2: $`col 03`,
      #   3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 58)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col 02~1 $col ~2 $col ~3 col 0~4
                   <dbl> <chr>           <chr>     <int> <ord>  
      1             1.23 a               A             1 a      
      2             2.23 b               B             2 b      
      3             3.23 c               C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>,
      #   and abbreviated variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 59)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero col 01$col 02~1 $col 0~2 $col ~3 col 0~4
                   <dbl> <chr>           <chr>      <int> <ord>  
      1             1.23 a               A              1 a      
      2             2.23 b               B              2 b      
      3             3.23 c               C              3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>,
      #   and abbreviated variable names 1: `col 01`$`col 02`,
      #   2: $`col 03`, 3: $`col 04`[,"A"], 4: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 60)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $col ~1 $col ~2 col 0~3
                   <dbl> <chr>             <chr>     <int> <ord>  
      1             1.23 a                 A             1 a      
      2             2.23 b                 B             2 b      
      3             3.23 c                 C             3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>,
      #   and abbreviated variable names 1: $`col 03`,
      #   2: $`col 04`[,"A"], 3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 61)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $col 0~1 $col ~2 col 0~3
                   <dbl> <chr>             <chr>      <int> <ord>  
      1             1.23 a                 A              1 a      
      2             2.23 b                 B              2 b      
      3             3.23 c                 C              3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>,
      #   and abbreviated variable names 1: $`col 03`,
      #   2: $`col 04`[,"A"], 3: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 62)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col ~1 col 0~2
                   <dbl> <chr>             <chr>       <int> <ord>  
      1             1.23 a                 A               1 a      
      2             2.23 b                 B               2 b      
      3             3.23 c                 C               3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"],
      #   2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 63)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 0~1 col 0~2
                   <dbl> <chr>             <chr>        <int> <ord>  
      1             1.23 a                 A                1 a      
      2             2.23 b                 B                2 b      
      3             3.23 c                 C                3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 64)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04~1 col 0~2
                   <dbl> <chr>             <chr>         <int> <ord>  
      1             1.23 a                 A                 1 a      
      2             2.23 b                 B                 2 b      
      3             3.23 c                 C                 3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 65)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[~1 col 0~2
                   <dbl> <chr>             <chr>          <int> <ord>  
      1             1.23 a                 A                  1 a      
      2             2.23 b                 B                  2 b      
      3             3.23 c                 C                  3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 66)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,~1 col 0~2
                   <dbl> <chr>             <chr>           <int> <ord>  
      1             1.23 a                 A                   1 a      
      2             2.23 b                 B                   2 b      
      3             3.23 c                 C                   3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 67)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"~1 col 0~2
                   <dbl> <chr>             <chr>            <int> <ord>  
      1             1.23 a                 A                    1 a      
      2             2.23 b                 B                    2 b      
      3             3.23 c                 C                    3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 68)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"A~1 col 0~2
                   <dbl> <chr>             <chr>             <int> <ord>  
      1             1.23 a                 A                     1 a      
      2             2.23 b                 B                     2 b      
      3             3.23 c                 C                     3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 69)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"A"~1 col 0~2
                   <dbl> <chr>             <chr>              <int> <ord>  
      1             1.23 a                 A                      1 a      
      2             2.23 b                 B                      2 b      
      3             3.23 c                 C                      3 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[2:3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 70)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col ~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>       <int>   <int> <ord>  
      1             1.23 a                 A               1       4 a      
      2             2.23 b                 B               2       5 b      
      3             3.23 c                 C               3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 71)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 0~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>        <int>   <int> <ord>  
      1             1.23 a                 A                1       4 a      
      2             2.23 b                 B                2       5 b      
      3             3.23 c                 C                3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and
      #   abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 72)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>         <int>   <int> <ord>  
      1             1.23 a                 A                 1       4 a      
      2             2.23 b                 B                 2       5 b      
      3             3.23 c                 C                 3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and abbreviated
      #   variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 73)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>          <int>   <int> <ord>  
      1             1.23 a                 A                  1       4 a      
      2             2.23 b                 B                  2       5 b      
      3             3.23 c                 C                  3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and abbreviated
      #   variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 74)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>           <int>   <int> <ord>  
      1             1.23 a                 A                   1       4 a      
      2             2.23 b                 B                   2       5 b      
      3             3.23 c                 C                   3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and abbreviated
      #   variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 75)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>            <int>   <int> <ord>  
      1             1.23 a                 A                    1       4 a      
      2             2.23 b                 B                    2       5 b      
      3             3.23 c                 C                    3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and abbreviated
      #   variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 76)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"A~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>             <int>   <int> <ord>  
      1             1.23 a                 A                     1       4 a      
      2             2.23 b                 B                     2       5 b      
      3             3.23 c                 C                     3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and abbreviated
      #   variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 77)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"A"~1 $[,"B"] col 0~2
                   <dbl> <chr>             <chr>              <int>   <int> <ord>  
      1             1.23 a                 A                      1       4 a      
      2             2.23 b                 B                      2       5 b      
      3             3.23 c                 C                      3       6 c      
      <tbl_format_footer(setup)>
      # ... with 1 more variable: `col 01`$`col 04`[3] <int>, and abbreviated
      #   variable names 1: $`col 04`[,"A"], 2: `col 05`
      # i Use `colnames()` to see all variable names
    Code
      tbl_format_setup(x, width = 78)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col ~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>       <int>   <int>   <int> <ord>  
      1             1.23 a                 A               1       4       7 a      
      2             2.23 b                 B               2       5       8 b      
      3             3.23 c                 C               3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 79)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 0~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>        <int>   <int>   <int> <ord>  
      1             1.23 a                 A                1       4       7 a      
      2             2.23 b                 B                2       5       8 b      
      3             3.23 c                 C                3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 80)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>         <int>   <int>   <int> <ord>  
      1             1.23 a                 A                 1       4       7 a      
      2             2.23 b                 B                 2       5       8 b      
      3             3.23 c                 C                 3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 81)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>          <int>   <int>   <int> <ord>  
      1             1.23 a                 A                  1       4       7 a      
      2             2.23 b                 B                  2       5       8 b      
      3             3.23 c                 C                  3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 82)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>           <int>   <int>   <int> <ord>  
      1             1.23 a                 A                   1       4       7 a      
      2             2.23 b                 B                   2       5       8 b      
      3             3.23 c                 C                   3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 83)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>            <int>   <int>   <int> <ord>  
      1             1.23 a                 A                    1       4       7 a      
      2             2.23 b                 B                    2       5       8 b      
      3             3.23 c                 C                    3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 84)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"A~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>             <int>   <int>   <int> <ord>  
      1             1.23 a                 A                     1       4       7 a      
      2             2.23 b                 B                     2       5       8 b      
      3             3.23 c                 C                     3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 85)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $col 04[,"A"~1 $[,"B"] $[,"C"] col 0~2
                   <dbl> <chr>             <chr>              <int>   <int>   <int> <ord>  
      1             1.23 a                 A                      1       4       7 a      
      2             2.23 b                 B                      2       5       8 b      
      3             3.23 c                 C                      3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable names 1: $`col 04`[,"A"], 2: `col 05`
    Code
      tbl_format_setup(x, width = 86)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $`col 04`[,"A"] $[,"B"] $[,"C"] col 0~1
                   <dbl> <chr>             <chr>               <int>   <int>   <int> <ord>  
      1             1.23 a                 A                       1       4       7 a      
      2             2.23 b                 B                       2       5       8 b      
      3             3.23 c                 C                       3       6       9 c      
      <tbl_format_footer(setup)>
      # ... with abbreviated variable name 1: `col 05`
    Code
      tbl_format_setup(x, width = 87)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $`col 04`[,"A"] $[,"B"] $[,"C"] `col 05`
                   <dbl> <chr>             <chr>               <int>   <int>   <int> <ord>   
      1             1.23 a                 A                       1       4       7 a       
      2             2.23 b                 B                       2       5       8 b       
      3             3.23 c                 C                       3       6       9 c       
      <tbl_format_footer(setup)>
    Code
      tbl_format_setup(x, width = 88)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $`col 04`[,"A"] $[,"B"] $[,"C"] `col 05`
                   <dbl> <chr>             <chr>               <int>   <int>   <int> <ord>   
      1             1.23 a                 A                       1       4       7 a       
      2             2.23 b                 B                       2       5       8 b       
      3             3.23 c                 C                       3       6       9 c       
      <tbl_format_footer(setup)>
    Code
      tbl_format_setup(x, width = 89)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $`col 04`[,"A"] $[,"B"] $[,"C"] `col 05`
                   <dbl> <chr>             <chr>               <int>   <int>   <int> <ord>   
      1             1.23 a                 A                       1       4       7 a       
      2             2.23 b                 B                       2       5       8 b       
      3             3.23 c                 C                       3       6       9 c       
      <tbl_format_footer(setup)>
    Code
      tbl_format_setup(x, width = Inf)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 3 x 3
      <tbl_format_body(setup)>
        column_zero_zero `col 01`$`col 02` $`col 03` $`col 04`[,"A"] $[,"B"] $[,"C"] `col 05`
                   <dbl> <chr>             <chr>               <int>   <int>   <int> <ord>   
      1             1.23 a                 A                       1       4       7 a       
      2             2.23 b                 B                       2       5       8 b       
      3             3.23 c                 C                       3       6       9 c       
      <tbl_format_footer(setup)>

# tbl_format_setup() results

    Code
      tbl_format_setup(as_tbl(mtcars), width = 80)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 32 x 11
      <tbl_format_body(setup)>
           mpg   cyl  disp    hp  drat    wt  qsec    vs    am  gear  carb
       * <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl> <dbl>
       1  21       6  160    110  3.9   2.62  16.5     0     1     4     4
       2  21       6  160    110  3.9   2.88  17.0     0     1     4     4
       3  22.8     4  108     93  3.85  2.32  18.6     1     1     4     1
       4  21.4     6  258    110  3.08  3.22  19.4     1     0     3     1
       5  18.7     8  360    175  3.15  3.44  17.0     0     0     3     2
       6  18.1     6  225    105  2.76  3.46  20.2     1     0     3     1
       7  14.3     8  360    245  3.21  3.57  15.8     0     0     3     4
       8  24.4     4  147.    62  3.69  3.19  20       1     0     4     2
       9  22.8     4  141.    95  3.92  3.15  22.9     1     0     4     2
      10  19.2     6  168.   123  3.92  3.44  18.3     1     0     4     4
      <tbl_format_footer(setup)>
      # ... with 22 more rows
      # i Use `print(n = ...)` to see more rows
    Code
      tbl_format_setup(as_tbl(mtcars), width = 30, n = 8)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 32 x 11
      <tbl_format_body(setup)>
          mpg   cyl  disp    hp
      * <dbl> <dbl> <dbl> <dbl>
      1  21       6  160    110
      2  21       6  160    110
      3  22.8     4  108     93
      4  21.4     6  258    110
      5  18.7     8  360    175
      6  18.1     6  225    105
      7  14.3     8  360    245
      8  24.4     4  147.    62
      <tbl_format_footer(setup)>
      # ... with 24 more rows, and
      #   7 more variables:
      #   drat <dbl>, wt <dbl>,
      #   qsec <dbl>, vs <dbl>,
      #   am <dbl>, gear <dbl>,
      #   carb <dbl>
      # i Use `print(n = ...)` to see more rows, and `colnames()` to see all variable names
    Code
      tbl_format_setup(as_tbl(trees), width = 30, n = 100)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 31 x 3
      <tbl_format_body(setup)>
         Girth Height Volume
         <dbl>  <dbl>  <dbl>
       1   8.3     70   10.3
       2   8.6     65   10.3
       3   8.8     63   10.2
       4  10.5     72   16.4
       5  10.7     81   18.8
       6  10.8     83   19.7
       7  11       66   15.6
       8  11       75   18.2
       9  11.1     80   22.6
      10  11.2     75   19.9
      11  11.3     79   24.2
      12  11.4     76   21  
      13  11.4     76   21.4
      14  11.7     69   21.3
      15  12       75   19.1
      16  12.9     74   22.2
      17  12.9     85   33.8
      18  13.3     86   27.4
      19  13.7     71   25.7
      20  13.8     64   24.9
      21  14       78   34.5
      22  14.2     80   31.7
      23  14.5     74   36.3
      24  16       72   38.3
      25  16.3     77   42.6
      26  17.3     81   55.4
      27  17.5     82   55.7
      28  17.9     80   58.3
      29  18       80   51.5
      30  18       80   51  
      31  20.6     87   77  
      <tbl_format_footer(setup)>
    Code
      # Unknown rows
      tbl_format_setup(as_unknown_rows(trees[1:9, ]), width = 30, n = 10)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: ?? x 3
      <tbl_format_body(setup)>
        Girth Height Volume
      * <dbl>  <dbl>  <dbl>
      1   8.3     70   10.3
      2   8.6     65   10.3
      3   8.8     63   10.2
      4  10.5     72   16.4
      5  10.7     81   18.8
      6  10.8     83   19.7
      7  11       66   15.6
      8  11       75   18.2
      9  11.1     80   22.6
      <tbl_format_footer(setup)>
    Code
      tbl_format_setup(as_unknown_rows(trees[1:10, ]), width = 30, n = 10)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: ?? x 3
      <tbl_format_body(setup)>
         Girth Height Volume
       * <dbl>  <dbl>  <dbl>
       1   8.3     70   10.3
       2   8.6     65   10.3
       3   8.8     63   10.2
       4  10.5     72   16.4
       5  10.7     81   18.8
       6  10.8     83   19.7
       7  11       66   15.6
       8  11       75   18.2
       9  11.1     80   22.6
      10  11.2     75   19.9
      <tbl_format_footer(setup)>
    Code
      tbl_format_setup(as_unknown_rows(trees[1:11, ]), width = 30, n = 10)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: ?? x 3
      <tbl_format_body(setup)>
         Girth Height Volume
       * <dbl>  <dbl>  <dbl>
       1   8.3     70   10.3
       2   8.6     65   10.3
       3   8.8     63   10.2
       4  10.5     72   16.4
       5  10.7     81   18.8
       6  10.8     83   19.7
       7  11       66   15.6
       8  11       75   18.2
       9  11.1     80   22.6
      10  11.2     75   19.9
      <tbl_format_footer(setup)>
      # ... with more rows
      # i Use `print(n = ...)` to see more rows
    Code
      # No rows
      tbl_format_setup(new_tbl(list(a = character(), b = logical())), width = 30)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 0 x 2
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      # ... with 2 variables:
      #   a <chr>, b <lgl>
      # i Use `colnames()` to see all variable names
    Code
      # No columns
      tbl_format_setup(as_tbl(trees[character()]), width = 30, n = 5L)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 31 x 0
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      # i Use `print(n = ...)` to see more rows
    Code
      # No rows, unknown
      tbl_format_setup(as_unknown_rows(trees[integer(), ]), width = 30, n = 5L)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: ?? x 3
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      # ... with 3 variables:
      #   Girth <dbl>,
      #   Height <dbl>,
      #   Volume <dbl>
      # i Use `colnames()` to see all variable names
    Code
      # No columns, unknown
      tbl_format_setup(as_unknown_rows(trees[, character()]), width = 30, n = 5L)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: ?? x 0
      <tbl_format_body(setup)>
      <tbl_format_footer(setup)>
      # ... with at least 5 rows
      #   total
      # i Use `print(n = ...)` to see more rows
    Code
      # Long table, unknown
      tbl_format_setup(as_unknown_rows(new_tbl(list(a = seq.int(10000)))), n = 5L,
      width = 30L)
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: ?? x 1
      <tbl_format_body(setup)>
            a
        <int>
      1     1
      2     2
      3     3
      4     4
      5     5
      <tbl_format_footer(setup)>
      # ... with more rows
      # i Use `print(n = ...)` to see more rows

# tbl_format_setup() for footnotes

    Code
      tbl_format_setup(width = 73, as_tbl(data_frame(xxxabc = 1, xxxdef = 1, xxxghi = 1,
        xxxjkl = 1, xxxmno = 1, xxxpqr = 1, xxxstu = 1, xxxvwx = 1, xxxyza = 1,
        xxxbcd = 1, xxxefg = 1, xxxhij = 1, xxxklm = 1, xxxnop = 1)))
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 1 x 14
      <tbl_format_body(setup)>
        xxxabc xxxdef xxxghi xxxjkl xxxmno xxxpqr xxxstu xxxvwx xxxyza xxxbcd
         <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>
      1      1      1      1      1      1      1      1      1      1      1
      <tbl_format_footer(setup)>
      # ... with 4 more variables: xxxefg <dbl>, xxxhij <dbl>, xxxklm <dbl>,
      #   xxxnop <dbl>
      # i Use `colnames()` to see all variable names

# tbl_format_setup() for footnotes with min_title_chars = 4

    Code
      tbl_format_setup(width = 73, as_tbl(data_frame(xxxabc = 1, xxxdef = 1, xxxghi = 1,
        xxxjkl = 1, xxxmno = 1, xxxpqr = 1, xxxstu = 1, xxxvwx = 1, xxxyza = 1,
        xxxbcd = 1, xxxefg = 1, xxxhij = 1, xxxklm = 1, xxxnop = 1)))
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 1 x 14
      <tbl_format_body(setup)>
        xxxabc xxxdef xxxghi xxxjkl xxxmno xxxpqr xxxstu xxxvwx xxxyza xxxbcd
         <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>
      1      1      1      1      1      1      1      1      1      1      1
      <tbl_format_footer(setup)>
      # ... with 4 more variables: xxxefg <dbl>, xxxhij <dbl>, xxxklm <dbl>,
      #   xxxnop <dbl>
      # i Use `colnames()` to see all variable names

# tbl_format_setup() for footnotes with UTF-8 output

    Code
      tbl_format_setup(width = 73, as_tbl(data_frame(xxxabc = 1, xxxdef = 1, xxxghi = 1,
        xxxjkl = 1, xxxmno = 1, xxxpqr = 1, xxxstu = 1, xxxvwx = 1, xxxyza = 1,
        xxxbcd = 1, xxxefg = 1, xxxhij = 1, xxxklm = 1, xxxnop = 1)))
    Output
      <pillar_tbl_format_setup>
      <tbl_format_header(setup)>
      # A data frame: 1 × 14
      <tbl_format_body(setup)>
        xxxabc xxxdef xxxghi xxxjkl xxxmno xxxpqr xxxstu xxxvwx xxxyza xxxbcd
         <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>  <dbl>
      1      1      1      1      1      1      1      1      1      1      1
      <tbl_format_footer(setup)>
      # … with 4 more variables: xxxefg <dbl>, xxxhij <dbl>, xxxklm <dbl>,
      #   xxxnop <dbl>
      # ℹ Use `colnames()` to see all variable names

